@@ -35,8 +35,8 @@ public:
     CallView(bool showCallers, TraceItemView* parentView,
              QWidget* parent=0);
 
-    virtual QWidget* widget() { return this; }
-    QString whatsThis() const;
+    QWidget* widget() Q_DECL_OVERRIDE { return this; }
+    QString whatsThis() const Q_DECL_OVERRIDE;
     bool showCallers() const { return _showCallers; }
 
 protected slots:
@@ -46,11 +46,11 @@ protected slots:
     void headerClicked(int);
 
 protected:
-    void keyPressEvent(QKeyEvent* event);
+    void keyPressEvent(QKeyEvent* event) Q_DECL_OVERRIDE;
 
 private:
-    CostItem* canShow(CostItem*);
-    void doUpdate(int, bool);
+    CostItem* canShow(CostItem*) Q_DECL_OVERRIDE;
+    void doUpdate(int, bool) Q_DECL_OVERRIDE;
     void refresh();
     void setCostColumnWidths();
 
